@@ -187,7 +187,7 @@ setMethod("[", "SpatialPointsDataFrame", function(x, i, j, ..., drop = TRUE) {
 	if (is.matrix(i))
 		stop("matrix argument not supported in SpatialPointsDataFrame selection")
 	if (is(i, "Spatial"))
-		i = !is.na(over(x, i))
+		i = !is.na(over(x, geometry(i)))
 	if (any(is.na(i))) 
 		stop("NAs not permitted in row index")
 	#coords.nrs = x@coords.nrs
